@@ -4,8 +4,11 @@
 
 #include <CMulticalendar.h>
 #include <CCalendar.h>
+#include <CTodo.h>
+
 #include <QStringList>
 
+
 #include <CalendarErrors.h>
 
 #include <main.cpp>
@@ -28,6 +31,13 @@ void usage_export(){
     cout << "\tDefaults to CAL_NAME.ics if no FILE_NAME given" << endl;
 }
 
+void usage_tasks_clear_done(){
+    cout << "Usage:" << endl;
+    cout << "\t--operation " << ARG_OP_VAL_TASKS_CLEAR_DONE.toLocal8Bit().constData()
+            << " --calendar CAL_NAME" << endl;
+           cout << "This will delete any of the tasks that have been completed." << endl;
+}
+
 void print_cals(CMulticalendar &mcal_instance){
     /*
      * Prints the list of calendars to std out
@@ -86,6 +96,10 @@ unsigned int arg_to_code(QString arg){
         return OPERATION_LIST;
     }
 
+    if(arg == ARG_OP_VAL_TASKS_CLEAR_DONE){
+        return OPERATION_TASKS_CLEAR_DONE;
+    }
+
     return OPERATION_UNKNOWN;
 
 }
@@ -227,7 +241,6 @@ bool do_operation(const QStringList args, const QString operation){
     bool result = false;
 
     switch (arg_to_code(operation)){
-
     case OPERATION_LIST:
         result = do_operation_list();
         break;
@@ -240,6 +253,10 @@ bool do_operation(const QStringList args, const QString operation){
         result = do_operation_export(args);
         break;
 
+    case OPERATION_TASKS_CLEAR_DONE:
+        result = do_operation_tasks_clear_done(args);
+        break;
+
     case OPERATION_UNKNOWN:
         cout << "Either the operation is unknown or not specified!" << endl;
         break;
@@ -399,10 +416,8 @@ bool do_operation_export(const QStringList args){
     cout << "calendar will be exported to:" << filename.toAscii().constData() << endl;
     result = mcalendar->exportCalendarEntries(calendar_id, filename.toAscii().constData(),errcode);
 
-    cout << "result:" << result << endl;
-    cout << "errcode:" << errcode << endl;
-
     if(errcode == CALENDAR_OPERATION_SUCCESSFUL){
+        cout << "The calendar was successfully exported." << endl;
         return true;
     } else {
         switch (errcode){
@@ -415,3 +430,64 @@ bool do_operation_export(const QStringList args){
     }
     \
 }
+
+bool do_operation_tasks_clear_done(const QStringList args){
+
+    QString calendar;
+    int calendar_id;
+
+    if(!get_calendar_from_cmd(args, calendar, calendar_id)){
+        cout << "That is not a valid calendar name" << endl;
+        usage_tasks_clear_done();
+        return false;
+    } else {
+        cout << "Deleting completed tasks in calendar with id:" << calendar_id << endl;
+    }
+
+    int errcode = 0;
+
+    CCalendar *cal = mcalendar->getCalendarById(calendar_id, errcode);
+    if (errcode != CALENDAR_OPERATION_SUCCESSFUL){
+        cout << "Failed to get the calendar" << endl;
+        return false;
+    }
+
+    vector<CTodo *> tasks = cal->getTodos(errcode);
+    if (errcode != CALENDAR_OPERATION_SUCCESSFUL){
+        cout << "Failed to get the tasks" << endl;
+        return false;
+    }
+
+    cout << "Total number of tasks(" << tasks.size() << "):" << endl;
+    int cerror = 0, cokay = 0;
+    for (unsigned int i=0; i<tasks.size(); i++){
+        CTodo *task = tasks.at(i);
+
+        if(task->getCompleted() > 0){
+            cal->deleteTodo(task->getId(),errcode);
+            if(errcode != CALENDAR_OPERATION_SUCCESSFUL){
+                cerror++;
+            } else {
+                cokay++;
+            }
+        }
+
+    }
+
+    cout << "Successful deletions: " << cokay << endl;
+    cout << "Failed deletions    : " << cerror << endl;
+
+    //release pointers
+    for (unsigned int i=0; i<tasks.size(); i++){
+        delete tasks.at(i);
+        tasks.at(i) = 0;
+
+    }
+
+    if(cerror == 0){
+        return true;
+    } else {
+        return false;
+    }
+
+}
