@@ -13,13 +13,14 @@ const QString ARG_VERIFY = "--verify";
 const QString ARG_OP_VAL_IMPORT = "import";
 const QString ARG_OP_VAL_EXPORT = "export";
 const QString ARG_OP_VAL_LIST = "list";
-
+const QString ARG_OP_VAL_TASKS_CLEAR_DONE = "tasks-clear-done";
 
 enum operationType {
     OPERATION_UNKNOWN = 0,
     OPERATION_IMPORT,
     OPERATION_EXPORT,
-    OPERATION_LIST
+    OPERATION_LIST,
+    OPERATION_TASKS_CLEAR_DONE
 };
 
 void print_cals(CMulticalendar&);
@@ -35,9 +36,11 @@ bool do_operation(const QStringList args, const QString operation);
 bool do_operation_list();
 bool do_operation_import(const QStringList args);
 bool do_operation_export(const QStringList args);
+bool do_operation_tasks_clear_done(const QStringList args);
 
 void usage_import();
 void usage_export();
+void usage_tasks_clear_done();
 
 #endif // FUNCTIONS_H
 
